==> polarion_rest_api_client-1.2.0-py3-none-any.whl: polarion_rest_api_client/open_api_client/models/documents_single_post_response_data_relationships_comments_data_item.py <==
# Copyright DB InfraGO AG and contributors
# SPDX-License-Identifier: Apache-2.0

from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.documents_single_post_response_data_relationships_comments_data_item_type import (
    DocumentsSinglePostResponseDataRelationshipsCommentsDataItemType,
)
from ..types import UNSET, Unset

T = TypeVar(
    "T", bound="DocumentsSinglePostResponseDataRelationshipsCommentsDataItem"
)


@_attrs_define
class DocumentsSinglePostResponseDataRelationshipsCommentsDataItem:
    """
    Attributes:
        id (Union[Unset, str]):  Example: MyProjectId/MySpaceId/MyDocumentId/MyCommentId.
        type (Union[Unset, DocumentsSinglePostResponseDataRelationshipsCommentsDataItemType]):
    """

    id: Union[Unset, str] = UNSET
    type: Union[
        Unset, DocumentsSinglePostResponseDataRelationshipsCommentsDataItemType
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(
        init=False, factory=dict
    )

    def to_dict(self) -> Dict[str, Any]:
        id = self.id

        type: Union[Unset, str] = UNSET
        if not isinstance(self.type, Unset):
            type = self.type.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if type is not UNSET:
            field_dict["type"] = type

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id", UNSET)

        _type = d.pop("type", UNSET)
        type: Union[
            Unset,
            DocumentsSinglePostResponseDataRelationshipsCommentsDataItemType,
        ]
        if isinstance(_type, Unset):
            type = UNSET
        else:
            type = DocumentsSinglePostResponseDataRelationshipsCommentsDataItemType(
                _type
            )

        documents_single_post_response_data_relationships_comments_data_item_obj = cls(
            id=id,
            type=type,
        )

        documents_single_post_response_data_relationships_comments_data_item_obj.additional_properties = (
            d
        )
        return documents_single_post_response_data_relationships_comments_data_item_obj

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> polarion_rest_api_client-1.4.1-py3-none-any.whl: polarion_rest_api_client/open_api_client/models/documents_single_post_response_data_relationships_comments_data_item.py <==
# Copyright DB InfraGO AG and contributors
# SPDX-License-Identifier: Apache-2.0

from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.documents_single_post_response_data_relationships_comments_data_item_type import (
    DocumentsSinglePostResponseDataRelationshipsCommentsDataItemType,
)
from ..types import UNSET, Unset

T = TypeVar(
    "T", bound="DocumentsSinglePostResponseDataRelationshipsCommentsDataItem"
)


@_attrs_define
class DocumentsSinglePostResponseDataRelationshipsCommentsDataItem:
    """
    Attributes:
        id (Union[Unset, str]):  Example: MyProjectId/MySpaceId/MyDocumentId/MyCommentId.
        type_ (Union[Unset, DocumentsSinglePostResponseDataRelationshipsCommentsDataItemType]):
    """

    id: Union[Unset, str] = UNSET
    type_: Union[
        Unset, DocumentsSinglePostResponseDataRelationshipsCommentsDataItemType
    ] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(
        init=False, factory=dict
    )

    def to_dict(self) -> dict[str, Any]:
        id = self.id

        type_: Union[Unset, str] = UNSET
        if not isinstance(self.type_, Unset):
            type_ = self.type_.value

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if type_ is not UNSET:
            field_dict["type"] = type_

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        id = d.pop("id", UNSET)

        _type_ = d.pop("type", UNSET)
        type_: Union[
            Unset,
            DocumentsSinglePostResponseDataRelationshipsCommentsDataItemType,
        ]
        if isinstance(_type_, Unset):
            type_ = UNSET
        else:
            type_ = DocumentsSinglePostResponseDataRelationshipsCommentsDataItemType(
                _type_
            )

        documents_single_post_response_data_relationships_comments_data_item_obj = cls(
            id=id,
            type_=type_,
        )

        documents_single_post_response_data_relationships_comments_data_item_obj.additional_properties = (
            d
        )
        return documents_single_post_response_data_relationships_comments_data_item_obj

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
